package cn.com.qmth.examcloud.exchange;

import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.autoconfigure.jdbc.DataSourceAutoConfiguration;
import org.springframework.boot.autoconfigure.web.servlet.MultipartAutoConfiguration;
import org.springframework.cloud.client.discovery.EnableDiscoveryClient;
import org.springframework.cloud.netflix.eureka.EnableEurekaClient;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.multipart.MultipartResolver;
import org.springframework.web.multipart.commons.CommonsMultipartResolver;

/**
 * Exchange不连接除Redis外的任何数据库. 说明 by wangwei.<br>
 * <p>
 * inner 提供云平台向南调用的中间件<br>
 * outer 提供第三方接入的中间件<br>
 */
@Configuration
@EnableEurekaClient
@EnableDiscoveryClient
@ComponentScan(basePackages = {"cn.com.qmth"})
@SpringBootApplication(exclude = {DataSourceAutoConfiguration.class, MultipartAutoConfiguration.class})
public class ExchangeApp {

    static {
        if (System.getProperty("log.commonLevel") == null) {
            System.setProperty("log.commonLevel", "INFO");
        }
        System.setProperty("hibernate.dialect.storage_engine", "innodb");
    }

    /**
     * main
     *
     * @param args
     * @author WANGWEI
     */
    public static void main(String[] args) {
        // AppBootstrap.run(ExchangeApp.class, args);
        SpringApplication.run(ExchangeApp.class, args);
    }

    @Bean(name = "multipartResolver")
    public MultipartResolver multipartResolver() {
        CommonsMultipartResolver resolver = new CommonsMultipartResolver();
        resolver.setDefaultEncoding("UTF-8");
        resolver.setResolveLazily(true);
        resolver.setMaxInMemorySize(2);
        resolver.setMaxUploadSize(100 * 1024 * 1024);
        return resolver;
    }

}